SupabasePushHandler class
Handles push operations (insert/update/delete) against Supabase.
Constructors
- SupabasePushHandler({required SupabaseClient client, required SupabaseConfig config})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pushOne(
SyncOperation op) → Future< PushResult> - Push a single operation to Supabase.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited